@@ -5,14 +5,13 @@ from __future__ import annotations
 import json
 import sys
 from copy import deepcopy
-from datetime import date, datetime
 from typing import Any, Final, Tuple, Union, get_args, get_origin, get_type_hints
 
 from .transformer import transform
 
 NoneType = type(None)
 
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 
 
 class _Field:
@@ -102,23 +101,6 @@ def _configure_init(cls, fields: Tuple[_Field, ...]) -> callable:
     return ns[name]
 
 
-def _configure_setattr(fields: Tuple[_Field, ...]) -> callable:
-    """
-    Configure __setattr__ method for the subclass
-
-    :param fields: list of field descriptors
-    :return: function performing correct setting for mutable attributes only
-    """
-    mutable_attributes = {f.name for f in fields if not f.is_final}
-
-    def _protected_setattr(self, key: str, value: Any) -> None:
-        if key not in mutable_attributes:
-            raise AttributeError(f"{key} is final or does not exist")
-        self.__setitem__(key, value)
-
-    return _protected_setattr
-
-
 # noinspection PyPep8Naming
 class jdict(dict):
     """
@@ -140,7 +122,6 @@ class jdict(dict):
             raise ValueError("Empty field list")
         fields = tuple(_Field.get_field(n, t) for n, t in hints.items())
         setattr(cls, "__init__", _configure_init(cls, fields))
-        setattr(cls, "__setattr__", _configure_setattr(fields))
 
     def __getattr__(self, name: str) -> Any:
         """
@@ -179,16 +160,5 @@ def patch_module(module: str) -> None:
     exec(code, vars(parsers))
 
 
-def _json_serial(_, obj) -> Any:
-    """JSON serializer for objects not serializable by default json code"""
-
-    if isinstance(obj, (datetime, date)):
-        return obj.isoformat()
-    raise TypeError("Type %s not serializable" % type(obj))
-
-
-def set_codec(codec: json) -> None:
+def set_json_decoder(codec: json) -> None:
     codec._default_decoder = codec.JSONDecoder(object_pairs_hook=jdict)
-    codec.JSONEncoder.default = (
-        _json_serial  # need more aggressive patching due to indent
-    )
